Learn R Programming

refund (version 0.1-40)

build_cluster_id: Build cluster ID vector from pffr metadata

Description

Maps each row of the vectorized model matrix back to its curve.

Usage

build_cluster_id(pffr_meta)

Value

Integer vector of length equal to the number of fitted rows.

Arguments

pffr_meta

The `pffr` metadata list from a fitted model.