Learn R Programming

refund (version 0.1-40)

center_functional_covariate: Center functional covariate column-wise

Description

Centers X so that colMeans(X) = 0, i.e., each evaluation point s has mean 0 across observations. This is the recommended centering for ff terms so the intercept can be interpreted as the global mean function.

Usage

center_functional_covariate(X)

Value

Centered matrix with same dimensions.

Arguments

X

Numeric matrix (n x n_xind) of functional covariate.