Learn R Programming

refund (version 0.1-40)

coef_get_predictions: Compute predictions for coefficient extraction

Description

Evaluates smooth term on grid and computes coefficients and standard errors.

Usage

coef_get_predictions(
  trm,
  data_grid,
  object_info,
  pffr_info,
  covmat,
  se,
  seWithMean,
  is_pcre,
  ci = "none",
  level = 0.95,
  coef_draws = NULL
)

Value

List with x, y, z coordinates, value, se, coef data frame, dim.

Arguments

trm

Smooth term object.

data_grid

Data frame from coef_make_data_grid.

object_info

List with: coefficients, cmX, Vp.

pffr_info

List with: yind_name.

covmat

Covariance matrix for SE computation.

se

Logical, compute standard errors?

seWithMean

Logical, include mean uncertainty?

is_pcre

Logical, is this a pcre term?

ci

One of "none", "pointwise", "simultaneous".

level

Confidence level for intervals.

coef_draws

Simulated coefficient perturbations (for simultaneous CIs).