Learn R Programming

refund (version 0.1-40)

coefboot.pffr: Simple bootstrap CIs for pffr (deprecated)

Description

**Deprecated**

`coefboot.pffr()` was renamed to [pffr_coefboot()] for consistency with the package naming conventions.

Usage

coefboot.pffr(
  object,
  n1 = 100,
  n2 = 40,
  n3 = 20,
  B = 100,
  ncpus = getOption("boot.ncpus", 1),
  parallel = c("no", "multicore", "snow"),
  cl = NULL,
  conf = c(0.9, 0.95),
  type = "percent",
  method = c("resample", "residual", "residual.c"),
  showProgress = TRUE,
  ...
)

Value

A list with similar structure as the return value of

coef.pffr, containing the original point estimates along with bootstrap CIs.

Arguments

object

a fitted pffr-model

n1

see coef.pffr

n2

see coef.pffr

n3

see coef.pffr

B

number of bootstrap replicates, defaults to (a measly) 100

ncpus

see boot. Defaults to getOption("boot.ncpus", 1L) (like boot).

parallel

see boot

cl

see boot

conf

desired levels of bootstrap CIs, defaults to 0.90 and 0.95

type

type of bootstrap interval, see boot.ci. Defaults to "percent" for percentile-based CIs.

method

either "resample" (default) to resample response trajectories, or "residual" to resample responses as fitted values plus residual trajectories or "residual.c" to resample responses as fitted values plus residual trajectories that are centered at zero for each gridpoint.

showProgress

TRUE/FALSE

...

further arguments handed to boot like e.g. strata for models with random effects.