Learn R Programming

refund (version 0.1-40)

expand_windows_to_maxwidth: Expand windows to uniform width

Description

Expands each window to have the same width (the maximum observed width), extending in whichever direction has room. This enables efficient matrix operations on uniformly-sized windows.

Usage

expand_windows_to_maxwidth(windows, max_col)

Value

Integer matrix where each row contains the column indices for the expanded window.

Arguments

windows

Integer matrix from [compute_integration_windows()] with columns: start, end, width.

max_col

Maximum valid column index (typically `ncol(smat)`).