Learn R Programming

refund (version 0.1-40)

make_bs_spec: Create B-spline specification for evaluation at new points

Description

Stores the knots and degree of a B-spline basis so it can be re-evaluated at new points while maintaining the same basis functions.

Usage

make_bs_spec(x, k)

Value

List with knots, boundary_knots, and degree.

Arguments

x

Numeric vector of points to build the basis on.

k

Number of basis functions.