Learn R Programming

refund (version 0.1-40)

pffr-formula: Modular Formula Parsing for pffr

Description

These functions provide a modular implementation of pffr formula parsing, extracting logical units from the main pffr() function for better maintainability and testing.

Arguments