Learn R Programming

refund (version 0.1-40)

pffr.check: Some diagnostics for a fitted pffr model (deprecated)

Description

**Deprecated**

`pffr.check()` was renamed to [pffr_check()] for consistency with the package naming conventions.

Usage

pffr.check(
  b,
  old.style = FALSE,
  type = c("deviance", "pearson", "response"),
  k.sample = 5000,
  k.rep = 200,
  rep = 0,
  level = 0.9,
  rl.col = 2,
  rep.col = "gray80",
  ...
)

Value

None, called for its side effect of producing diagnostic plots.

Arguments

b

a fitted pffr-object

old.style

If you want old fashioned plots, exactly as in Wood, 2006, set to TRUE.

type

type of residuals, see residuals.gam, used in all plots.

k.sample

Above this k testing uses a random sub-sample of data.

k.rep

how many re-shuffles to do to get p-value for k testing.

rep

passed to qq.gam when old.style is FALSE.

level

passed to qq.gam when old.style is FALSE.

rl.col

passed to qq.gam when old.style is FALSE.

rep.col

passed to qq.gam when old.style is FALSE.

...

extra graphics parameters to pass to plotting functions.