Learn R Programming

refund (version 0.1-40)

pffr_build_label_map: Build the label map from terms to smooth labels

Description

Build the label map from terms to smooth labels

Usage

pffr_build_label_map(
  new_term_strings,
  terms,
  add_f_int,
  int_string,
  m_smooth,
  where_specials,
  ffpc_terms,
  formula_env,
  yindex_vec_name
)

Value

The label_map list.

Arguments

new_term_strings

Transformed term strings.

terms

Original parsed terms.

add_f_int

Whether functional intercept was added.

int_string

Intercept string.

m_smooth

List of smooth objects from fitted model.

where_specials

List of special term indices.

ffpc_terms

Processed ffpc terms.

formula_env

Formula environment.

yindex_vec_name

Y-index vector name.