This is simply a wrapper for gam.check().
pffr_check(
b,
old.style = FALSE,
type = c("deviance", "pearson", "response"),
k.sample = 5000,
k.rep = 200,
rep = 0,
level = 0.9,
rl.col = 2,
rep.col = "gray80",
...
)None, called for its side effect of producing diagnostic plots and printing basis dimension checks.
a fitted pffr-object
If you want old fashioned plots, exactly as in Wood, 2006, set to TRUE.
type of residuals, see residuals.gam, used in
all plots.
Above this k testing uses a random sub-sample of data.
how many re-shuffles to do to get p-value for k testing.
passed to qq.gam when old.style is FALSE.
passed to qq.gam when old.style is FALSE.
passed to qq.gam when old.style is FALSE.
passed to qq.gam when old.style is FALSE.
extra graphics parameters to pass to plotting functions.