Learn R Programming

refund (version 0.1-40)

validate_and_expand_xind: Validate and expand xind to matrix form

Description

Validates that xind has the correct dimensions and is in increasing order, then expands a vector or single-row matrix to a full n x nxgrid matrix. Used by [ff()] and [sff()].

Usage

validate_and_expand_xind(xind, n, nxgrid, arg_name = "xind")

Value

Matrix of x-index values (n x nxgrid).

Arguments

xind

Vector or matrix of x-index values.

n

Number of observations.

nxgrid

Number of grid points (columns expected).

arg_name

Name of the argument for error messages.