## S3 method for class 'pffr':
coef(object, raw = FALSE, se = TRUE, freq = FALSE, n1 = 100, n2 = 40, n3 = 20, ...)pffr-objectobject$coefficientsobject$Vp for variability
estimates, else use object$Ve. See
gamObjectraw==FALSE, a list containing ptermsa matrix containing the parametric /
non-functional coefficients (and, optionally, their se's)smtermsa named list with one entry for each
smooth term in the model. Each entry containscoefa matrix giving the grid values over
the covariates, the estimated effect (and, optionally,
the se's). The first covariate varies the fastest.x, y, zthe unique gridpoints used to evaluate the
smooth/coefficient function/coefficient surfacexlim, ylim, zlimthe extent of the x/y/z-axesxlab, ylab, zlabthe names of the covariates
for the x/y/z-axesdimthe dimensionality of
the effectmainthe label of the smooth term
(a short label, same as the one used insummary.pffr)