Evaluates smooth term on grid and computes coefficients and standard errors.
coef_get_predictions(
trm,
data_grid,
object_info,
pffr_info,
covmat,
se,
seWithMean,
is_pcre,
ci = "none",
level = 0.95,
coef_draws = NULL
)List with x, y, z coordinates, value, se, coef data frame, dim.
Smooth term object.
Data frame from coef_make_data_grid.
List with: coefficients, cmX, Vp.
List with: yind_name.
Covariance matrix for SE computation.
Logical, compute standard errors?
Logical, include mean uncertainty?
Logical, is this a pcre term?
One of "none", "pointwise", "simultaneous".
Confidence level for intervals.
Simulated coefficient perturbations (for simultaneous CIs).