ensure_grid_axis_attributes: Ensure evaluation grid has axis attributes used by coef extraction
Description
Ensure evaluation grid has axis attributes used by coef extraction
Usage
ensure_grid_axis_attributes(d, trm, is_pcre, pffr_info)
Value
Data frame with xm/ym/zm attributes set.
Arguments
- d
Evaluation grid data frame.
- trm
Smooth term object.
- is_pcre
Logical, is this a pcre term?
- pffr_info
List with yind_name.