Expands each window to have the same width (the maximum observed width), extending in whichever direction has room. This enables efficient matrix operations on uniformly-sized windows.
expand_windows_to_maxwidth(windows, max_col)Integer matrix where each row contains the column indices for the expanded window.
Integer matrix from [compute_integration_windows()] with columns: start, end, width.
Maximum valid column index (typically `ncol(smat)`).