predict.wnet: Prediction for generalized elastic net in the wavelet domain
Description
Prediction function fro wnet object.Usage
## S3 method for class 'wnet':
predict(object, newx, covt = NULL, ...)
Arguments
object
a fitted wnet-object
newx
Matrix of new values for x at which predictions are to be made.
covt
Matrix of new covariates.