Learn R Programming

refund (version 0.1-13)

residuals.pffr: Obtain residuals and fitted values for a pffr models

Description

See predict.pffr for alternative options to extract estimated values from a pffr object. "Fitted values" here refers to the estimated additive predictor values, these will not be on the scale of the response for models with link functions.

Usage

## S3 method for class 'pffr':
residuals(object, reformat = TRUE, ...)

## S3 method for class 'pffr':
fitted(object, reformat = TRUE, ...)

Arguments

object
a fitted pffr-object
reformat
logical, defaults to TRUE. Should residuals be returned in n x yindex matrix form (regular grid data) or, respectively, in the shape of the originally supplied ydata argument (sparse/irregular data), or, if FALSE,
...
other arguments, passed to residuals.gam.

Value

  • A matrix or ydata-like data.frame or a vector of residuals / fitted values (see reformat-argument)