Validates that xind has the correct dimensions and is in increasing order, then expands a vector or single-row matrix to a full n x nxgrid matrix. Used by [ff()] and [sff()].
validate_and_expand_xind(xind, n, nxgrid, arg_name = "xind")Matrix of x-index values (n x nxgrid).
Vector or matrix of x-index values.
Number of observations.
Number of grid points (columns expected).
Name of the argument for error messages.